# mline

**mline** is a lightweight YAML-based pipeline engine.

More documentation coming soon.


# Installation

Install default version from the
[Python Package Index](https://pypi.org/project/mline/):

```
pip install mline
```
